#!/bin/bash
#
#  INTEL CONFIDENTIAL
#
#  Copyright 2008-2014 Intel Corporation All Rights Reserved.
#
#  The source code contained or described herein and all documents related to
#  the source code ("Material") are owned by Intel Corporation or its
#  suppliers or licensors.
#
#  Title to the Material remains with Intel Corporation or its suppliers and
#  licensors. The Material contains trade secrets and proprietary and
#  confidential information of Intel or its suppliers and licensors.
#  The Material is protected by worldwide copyright and trade secret laws and
#  treaty provisions. No part of the Material may be used, copied, reproduced,
#  modified, published, uploaded, posted, transmitted, distributed,
#  or disclosed in any way without Intel's prior express written permission.
#
#  No license under any patent, copyright, trade secret or other intellectual
#  property right is granted to or conferred upon you by disclosure
#  or delivery of the Materials, either expressly, by implication, inducement,
#  estoppel or otherwise. Any license under such intellectual property rights
#  must be express and approved by Intel in writing.
#

. ./testslib.sh
ParseTestArguments $@

Print " " 4
Print "NM HPIO power reading test" 4 34
Print " " 4
# this test requires a MIC board - need to verify it works
scriptError=0
suppressCmdError=0 # compCode from response will be located in 'errorCode' variable

# input parameters for command
manufId=0x157
mode=1
domainId=0x04
policyId=0x10
## STEP 1
GetNmCapabilities "$domainId $policyId"
if [ "$error" != "0" ]; then
  Print "GetNmCapabilities command failed! Response: $rsp" 0 31
  Print "TEST FAILED " 0 31
  exit 1
fi
nmMaxHPIOPower=$(( 0x$c7$c6 ))
nmMinHPIOPower=$(( 0x$c9$c8 ))
Print "GetNmCapabilities, max Memory Power[W]: $nmMaxHPIOPower" 4
Print "GetNmCapabilities, min Memory Power[W]: $nmMinHPIOPower" 4

## STEP 2
GetNMStatistics "$mode $domainId $policyId"
if [ "$error" != "0" ]; then
  Print "GetNmStatistics command failed! Response: $rsp" 0 31
  Print "TEST FAILED " 0 31
  exit 1
fi
nmCurrentPowerRead=$(( 0x$b6$b5 ))
Print "GetNMStatistics current power read [W]: $nmCurrentPowerRead" 4

if [ $nmCurrentPowerRead -gt $nmMaxHPIOPower ]; then
  Print "GetNmStatistics HPIO power read ($nmCurrentPowerRead) exceeded GetNMCapabilities max HPIO Power value ($nmMaxHPIOPower)!" 0 31
  scriptError=1
fi

if [ $nmCurrentPowerRead -le 0 ]; then
  Print "GetNmStatistics memory power read ($nmCurrentPowerRead) below or equal 0!" 0 31
  scriptError=1
fi

## STEP 3
Print "Generating load on HPIO domain." 4
# generate load on HPIO domain
. ${applyHpioLoadScript}
sleep 5

## STEP 4
GetNMStatistics "$mode $domainId $policyId"
if [ "$error" != "0" ]; then
  Print "GetNmStatistics command failed! Response: $rsp" 0 31
  Print "TEST FAILED " 0 31
  exit 1
fi

nmCurrentPowerRead=$(( 0x$b6$b5 ))
Print "GetNMStatistics current power read [W]: $nmCurrentPowerRead" 4
if [ $nmCurrentPowerRead -gt $nmMaxHPIOPower ]; then
  Print "GetNmStatistics HPIO power read ($nmCurrentPowerRead) exceeded GetNMCapabilities max HPIO Power value ($nmMaxHPIOPower)!" 0 31
  scriptError=1
fi

if [ $nmCurrentPowerRead -le 0 ]; then
  Print "GetNmStatistics HPIO power read ($nmCurrentPowerRead) below or equal 0!" 0 31
  scriptError=1
fi

# just in case kill the power load tools
Print "Stop generating load on HPIO power domain." 4
. ${stopLoadScript}

if [ $scriptError -eq 1 ]; then
    Print " " 0
    Print "TEST FAILED " 0 31
    Print " " 0
    exit 1
else 
    Print " " 4
    Print "TEST PASSED " 4 34
    Print " " 4
    exit 0
fi
